package guanlixitong

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/enterprise/src/guanlixitong/model"
)

type recruitment struct {
	Table
	resume       resume
	fields       string `data:"title,degree,seniority,salary,content,total,count,recruitment_status,user_uid"`
	create       string `name:"create title* degree* seniority* salary* content* total*=1" role:"leader"`
	modify       string `name:"modify content*" role:"leader"`
	remove       string `name:"remove" role:"leader"`
	start        string `name:"start" role:"leader"`
	stop         string `name:"stop" role:"leader"`
	resumeInsert string `name:"create name* info* mobile* email degree*" role:"void"`
}

func (s recruitment) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case model.TITLE:
		m.Push(arg[0], "高级销售")
		m.Push(arg[0], "中级销售")
		m.Push(arg[0], "初级销售")
	case model.DEGREE:
		m.Push(arg[0], "博士")
		m.Push(arg[0], "硕士")
		m.Push(arg[0], "本科")
		m.Push(arg[0], "大专")
		m.Push(arg[0], "高中")
		m.Push(arg[0], "中专")
		m.Push(arg[0], "初中")
	case model.SENIORITY:
		m.Push(arg[0], "10年以上")
		m.Push(arg[0], "5-10年")
		m.Push(arg[0], "3-5年")
		m.Push(arg[0], "1-3年")
		m.Push(arg[0], "应届生")
		m.Push(arg[0], "在校生")
	case model.SALARY:
		m.Push(arg[0], "45K以上")
		m.Push(arg[0], "35-45K")
		m.Push(arg[0], "25-35K")
		m.Push(arg[0], "15-25K")
		m.Push(arg[0], "15K以下")
	case model.CONTENT:
	default:
		s.Table.Inputs(m, arg...)
	}
}
func (s recruitment) List(m *ice.Message, arg ...string) {
	s.ValueList(m, arg).Table(func(value ice.Maps) {
		switch RecruitmentStatus(kit.Int(value[model.RECRUITMENT_STATUS])) {
		case RecruitmentCreate:
			m.PushButton(s.Start, s.Modify, s.Remove)
		case RecruitmentStart:
			if m.Option(model.MARKET_UID) != "" {
				m.PushButton(s.ResumeInsert)
			} else if s.IsLeader(m) {
				m.PushButton(s.ResumeInsert, s.MarketInsert, s.Modify, s.Stop)
			} else {
				m.PushButton(s.ResumeInsert)
			}
		case RecruitmentStop:
			m.PushButton()
		}
	}).Display("")
}
func (s recruitment) Start(m *ice.Message, arg ...string) {
	s.ValueModify(m, model.STATUS, kit.Format(RecruitmentStart))
}
func (s recruitment) Stop(m *ice.Message, arg ...string) {
	s.ValueModify(m, model.STATUS, kit.Format(RecruitmentStop))
}
func (s recruitment) ResumeInsert(m *ice.Message, arg ...string) {
	m.Cmdy(s.resume, s.Insert, arg, m.OptionSimple(model.GROUP_UID, model.USER_UID))
}

func init() { ice.TeamCtxCmd(recruitment{}) }

type RecruitmentStatus int

const (
	RecruitmentCreate RecruitmentStatus = iota
	RecruitmentStart
	RecruitmentStop
)

var RecruitmentStatusList = map[RecruitmentStatus]string{
	RecruitmentCreate: "create",
	RecruitmentStart:  "start",
	RecruitmentStop:   "stop",
}

func (s RecruitmentStatus) String() string { return RecruitmentStatusList[s] }
